@@ -2,8 +2,9 @@ package Import::Into;
 
 use strict;
 use warnings FATAL => 'all';
+use Module::Runtime;
 
-our $VERSION = '1.002001'; # 1.2.1
+our $VERSION = '1.002003';
 
 sub _prelude {
   my $target = shift;
@@ -24,8 +25,9 @@ sub _prelude {
 sub _make_action {
   my ($action, $target) = @_;
   my $version = ref $target && $target->{version};
-  my $ver_check = $version ? '$_[0]->VERSION($version);' : '';
-  eval _prelude($target).qq{sub { $ver_check shift->$action(\@_) }}
+  my $ver_check = $version ? ', $version' : '';
+  eval _prelude($target)
+    . qq{sub { Module::Runtime::use_module( shift$ver_check )->$action(\@_) }}
     or die "Failed to build action sub to ${action} for ${target}: $@";
 }
 
@@ -45,7 +47,7 @@ __END__
 
 =head1 NAME
 
-Import::Into - import packages into other packages
+Import::Into - Import packages into other packages
 
 =head1 SYNOPSIS
 
@@ -53,9 +55,6 @@ Import::Into - import packages into other packages
 
   use Import::Into;
 
-  use Thing1 ();
-  use Thing2 ();
-
   # simple
   sub import {
     Thing1->import::into(scalar caller);
@@ -109,8 +108,8 @@ C<Import::Into> provides global methods to make this painless.
 
 =head2 $package->import::into( $target, @arguments );
 
-A global method, callable on any package.  Imports the given package into
-C<$target>.  C<@arguments> are passed along to the package's import method.
+A global method, callable on any package.  Loads and imports the given package
+into C<$target>.  C<@arguments> are passed along to the package's import method.
 
 C<$target> can be an package name to export to, an integer for the
 caller level to export to, or a hashref with the following options:
@@ -192,7 +191,8 @@ an exporter and a pragma.
 
 So, a solution for that is:
 
-  my $sub = eval "package $target; sub { shift->import(\@_) }";
+  use Module::Runtime;
+  my $sub = eval "package $target; sub { use_module(shift)->import(\@_) }";
   $sub->($thing, @import_args);
 
 which means that import is called from the right place for pragmas to take
@@ -209,12 +209,12 @@ in the directive then need to be fetched using C<caller>:
   my $sub = eval qq{
     package $target;
   #line $line "$file"
-    sub { shift->import(\@_) }
+    sub { use_module(shift)->import(\@_) }
   };
   $sub->($thing, @import_args);
 
 And you need to switch between these implementations depending on if you are
-targetting a specific package, or something in your call stack.
+targeting a specific package, or something in your call stack.
 
 Remembering all this, however, is excessively irritating. So I wrote a module
 so I didn't have to anymore. Loading L<Import::Into> creates a global method
@@ -252,16 +252,13 @@ For more craziness of this order, have a look at the article I wrote at
 L<http://shadow.cat/blog/matt-s-trout/madness-with-methods> which covers
 coderef abuse and the C<${\...}> syntax.
 
-Final note: You do still need to ensure that you already loaded C<$thing> - if
-you're receiving this from a parameter, I recommend using L<Module::Runtime>:
-
-  use Import::Into;
-  use Module::Runtime qw(use_module);
-
-  use_module($thing)->import::into($target, @import_args);
-
 And that's it.
 
+=head1 SEE ALSO
+
+I gave a lightning talk on this module (and L<curry> and L<Safe::Isa>) at
+L<YAPC::NA 2013|https://www.youtube.com/watch?v=wFXWV2yY7gE&t=46m05s>.
+
 =head1 ACKNOWLEDGEMENTS
 
 Thanks to Getty for asking "how can I get C<< use strict; use warnings; >>
@@ -276,6 +273,8 @@ mst - Matt S. Trout (cpan:MSTROUT) <mst@shadowcat.co.uk>
 
 haarg - Graham Knop (cpan:HAARG) <haarg@haarg.org>
 
+Mithaldu - Christian Walde (cpan:MITHALDU) <walde.christian@gmail.com>
+
 =head1 COPYRIGHT
 
 Copyright (c) 2012 the Import::Into L</AUTHOR> and L</CONTRIBUTORS>
